-- *********************** --
-- 모바일메시지에서 사용하는 에러코드 사전등록(참고용)
-- *********************** --
-- KAKAO, NAVER, MT(SMS/MMS) 발송에서 사용하는 에러코드 테이블
-- MySql
-- DROP TABLE IF EXISTS app_error_code;
-- *********************** --
CREATE TABLE IF NOT EXISTS app_error_code (
  APP_GUBUN varchar(8) NOT NULL DEFAULT '' COMMENT '앱구분',
  APP_CODE  varchar(4) NOT NULL DEFAULT '' COMMENT '에러코드',
  MESSAGE varchar(100) DEFAULT NULL COMMENT '에레메시지',
  DESCRIPTION varchar(300) DEFAULT NULL COMMENT '에러_설명',
  KEY APP_GUBUN (APP_GUBUN),
  KEY APP_CODE (APP_CODE)
) ENGINE=InnoDB DEFAULT CHARSET=euckr COMMENT='에러코드 테이블';
--
-- ######################################################
-- 가온
-- ######################################################
-- -- 테이블의 덤프 데이터 app_error_code
--
--     가온 상태값 CUR_STATE
--     0 - 메시지 등록
--     1 - 메시지 발송 완료
--     2 - 메시지 결과 수신 완료
--     3 - 문자 발송
--
--     RSLT_CODE_APP(GROUP)
--     G1xx - 메시지 데이터 필드 유효성 체크
--     G2xx - 템플릿 유효성 체크
--     G3xx - 메시지 내용 유효성 체크
--     G4xx - 발송량 체크
--     G7xx - 테스트 베드
--     G9xx - 문자로 전환 가능한 에러, 서버연동 이상.
--
--
--     ERROR_CODE
--     ┌──────────────-┬─────────────────────────────────────────────────────────────────────┐
--     │  ERROR_CODE   │                         DESCRIPTION                                 │
--     ├───────────────┼─────────────────────────────────────────────────────────────────────┤
--     │     G100      │ APP_GUBUN에 KAKAO, NAVER 이외의 값이 입력됨(대문자만 입력가능)      │
--     │     G101      │ 전화번호 에러                                                       │
--     │     G200      │ TEMPLATE_CODE 테이블에 템플릿이 존재하지 않음                       │
--     │     G201      │ 버튼의 JSON형식이 맞지 않음                                         │
--     │     G202      │ 버튼이 존재하나 url이 http:// 혹은 https://로 시작하지 않음         │
--     │     G300      │ 메시지 내용이 빈값                                                  │
--     │     G301      │ GAON_MSG_TYPE이 S인 경우 내용이 90Byte 초과                         │
--     │     G400      │ 각 번호별 일일 발송량 초과                                          │
--     │     G777      │ TEST BED                                                            │
--     │     G900      │ 서버연결 실패                                                       │
--     │     G901      │ 인증 실패                                                           │
--     │     G902      │ 타임 아웃                                                           │
--     │     G903      │ 메시지 내용이 제한 길이를 초과                                      │
--     └───────────────┴─────────────────────────────────────────────────────────────────────┘
-- $ G9xx 포함 카카오 에러는 모두 문자처리
--
-- ######################################################
-- 가온
-- ######################################################
-- ######################################################
-- 누리 상태 값
-- ######################################################
--     0 - 메시지 등록( 9 - 긴급메시지 처리, 0,1 데이터 보다 최우선 처리)
--     1 - 발송 대기상태 데이터
--     6 - 발송 Queue  적재(발송진행중 데이터)
--     2 - 발송 완료(이통사 결과 대기, MMS G/W 접수 완료, 전송중, 성공실패 확인 불가)
--     3 - 종료, 메시지 처리상태 완료, 성공 또는 실패 결과 회신
-- ######################################################
-- 누리 상태 값
-- ######################################################


-- -- 테이블의 덤프 데이터 app_error_code
-- 카카오 에러코드
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '0000', 'SUCCESS', '성공');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1001', 'NoJsonBody', 'Request Body가 Json형식이 아님');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1002', 'InvalidHubPartnerKey', '허브 파트너 키가 유효하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1003', 'InvalidSenderKey', '발신 프로필 키가 유효하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1004', 'NoValueJsonElement', 'Request Body(Json)에서 name을 찾을 수 없음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1006', 'DeletedSender', '삭제된 발신프로필. (메시지 사업 담당자에게 문의)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1007', 'StoppedSender', '차단 상태의 발신프로필. (메시지 사업 담당자에게 문의)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1011', 'ContractNotFound', '계약정보를 찾을 수 없음. (메시지 사업 담당자에게 문의)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1012', 'InvalidUserKeyException', '잘못된 형식의 유저키 요청');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1013', 'InvalidAppLink', '유효하지 않은 app연결');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1014', 'InvalidBizNum', '유효하지 않은 사업자번호');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1015', 'TalkUserIdNotFonud', '유효하지 않은 app user id 요청');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1016', 'BizNumNotEqual', '사업자등록번호 불일치');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1020', 'InvalidReceiveUser', '전화번호 or app user id가 유효하지 않거나 미입력 요청');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1021', 'BlockedProfile', '차단 상태의 카카오톡 채널 (카카오톡 채널 운영툴에서 확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1022', 'DeactivatedProfile', '닫힘 상태의 카카오톡 채널 (카카오톡 채널 운영툴에서 확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1023', 'DeletedProfile', '삭제된 카카오톡 채널 (카카오톡 채널 운영툴에서 확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1024', 'DeletingProfile', '삭제대기 상태의 카카오톡 채널 (카카오톡 채널 운영툴에서 확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1025', 'SpammedProfile', '메시지차단 상태의 카카오톡 채널 (카카오톡 채널 운영툴에서확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1026', 'UnableUseMessageType', '메시지차단 상태의 카카오톡 채널 (카카오톡 채널 운영툴에서확인)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '1030', 'InvalidParameterException', '잘못된 파라메터 요청');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '2003', 'FailedToSendMessageByNoFriendshipException', '(테스트 발송) 카카오톡 채널을 추가하지 않았음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '2004', 'FailedToMatchTemplateException', '템플릿 일치 확인시 오류 발생(내부 오류 발생)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '2006', 'FailedToMatchSerialNumber', '시리얼넘버 형식 불일치');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3000', 'UnexpectedException', '예기치 않은 오류 발생');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3005', 'AckTimeoutException', '메시지를 발송했으나 수신확인 안됨 (성공불확실)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3006', 'FailedToSendMessageException', '내부 시스템 오류로 메시지 전송 실패');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3008', 'InvalidPhoneNumberException', '전화번호 오류');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3010', 'JsonParseException', 'Json 파싱 오류');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3011', 'MessageNotFoundException', '메시지가 존재하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3012', 'SerialNumberDuplicatedException', '메시지 일련번호가 중복됨');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3013', 'MessageEmptyException', '메시지가 비어 있음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3014', 'MessageLengthOverLimitException', '메시지 길이 제한 오류 (템플릿별 제한 길이 또는 1000자 초과)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3015', 'TemplateNotFoundException', '템플릿을 찾을 수 없음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3016', 'NoMatchedTemplateException', '메시지 내용이 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3018', 'NoSendAvailableException', '메시지를 전송할 수 없음, 카톡 설치 안됨, 알림톡 차단');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3025', 'ExceedMaxVariableLengthException', '변수 글자수 제한 초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3026', 'Button chat_extra(event)-InvalidExtra(EventName)Exception', '상담/봇 전환 버튼 extra,  event 글자수 제한 초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3027', 'NoMatchedTemplateButtonException / NoMatchedTemplateQuickReplyException', '메시지 버튼/바로연결이 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3028', 'NoMatchedTemplateTitleException', '메시지 강조 표기 타이틀이 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3029', 'ExceedMaxTitleLengthException', '메시지 강조 표기 타이틀 길이 제한 초과 (50자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3030', 'NoMatchedTemplateWithMessageTypeException', '메시지 타입과 템플릿 강조유형이 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3031', 'NoMatchedTemplateHeaderException', '헤더가 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3032', 'ExceedMaxHeaderLengthException', '헤더 길이 제한 초과(16자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3033', 'NoMatchedTemplateItemHighlightException', '아이템 하이라이트가 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3034', 'ExceedMaxItemHighlightTitleLengthException', '아이템 하이라이트 타이틀 길이 제한 초과(이미지 없는 경우 30자, 이미지 있는 경우 21자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3035', 'ExceedMaxItemHighlightDescriptionLengthException', '아이템 하이라이트 디스크립션 길이 제한 초과(이미지 없는경우 19자, 이미지 있는 경우 14자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3036', 'NoMatchedTemplateItemListException', '아이템 리스트가 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3037', 'ExceedMaxItemDescriptionLengthException', '아이템 리스트의 아이템의 디스크립션 길이 제한 초과(23자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3038', 'NoMatchedTemplateItemSummaryException', '아이템 요약정보가 템플릿과 일치하지 않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3039', 'ExceedMaxItemSummaryDescriptionLengthException', '아이템 요약정보의 디스크립션 길이 제한 초과(14자)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '3040', 'InvalidItemSummary', '아이템 요약정보의 디스크립션에 허용되지 않은 문자 포함(통화기호/코드, 숫자,  콤마,  소수점, 공백을 제외한 문자 포함)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '4000', 'ResponseHistoryNotFoundException', '메시지 전송 결과를 찾을 수 없음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '4001', 'UnknownMessageStatusError', '알 수 없는 메시지 상태');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '5000', 'InvalidTestUser', '(테스트 발송) 관리자 혹은 일회성 인증을 받은 사용자가 아님');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '5001', 'DailyTestLimitExceeded', '(테스트 발송) 일일 발송량 초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '9991', 'fail', '발송실패(발송정보알수없음), 모바일데이터가 꺼져있음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '9998', 'noservice', '현재 서비스를 제공하고 있지 않습니다.\n시스템에 문제가 발생하여 담당자가 확인하고 있는 경우');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', '9999', 'unkownerror', '시스템에서 알 수 없는 문제가 발생하였습니다.\n담당자가 확인 중입니다.\n시스템에 문제가 발생하여 담당자가 확인하고 있는 경우');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('KAKAO', 'K991', 'connectFail', 'APP G/W >> KAKAO 서버 연결실패');

-- -- 네이버 에러코드
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '0000', 'SUCCESS', '메세지가 유저에게 앱과 웹으로 성공적으로전송되었습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '0001', '', '메세지가 유저에게 웹으로 전송되었으나 앱전송에는 실패하였습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '1001', '', 'AgentKey나 PartnerKey가 누락되었습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '1002', '', '보내기 API의 요청 Body에 문제가있습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '1003', '', '전화번호나 액세스 토큰 중 적어도 하나의 파라미터가 필요합니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '1004', '', '전화번호 패턴이 잘못되었습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '1005', '', '파트너키나 발송그룹키가 반드시 있어야 합니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2001', '', '템플릿에 필요한 파라미터가 부족합니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2002', '', '템플릿 아이디가 존재하지않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2003', '', '템플릿에 필요한 파라미터가 일치하지 않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2004', '', '템플릿에 필요한 버튼 갯수와 요청한 버튼 갯수가 일치하지 않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2005', '', '템플릿에 필요한 파라미터가 일치하지 않습니다. 버튼코드를 확인하세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2006', '', '등록된 템플릿과 일치하지 않는 메세지(message) 파라미터입니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2007', '', '승인되지 않은 템플릿은 발송할 수 없습니다. 템플릿 승인 상태를 확인하세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2008', '', '등록된 템플릿과 메세지 파라미터를 비교하던 중 오류가 발생하였습니다. 2006 응답코드와 거의 동일한 상황이나, 특수문자에 의해 불일치가 있는경우입니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2009', '', '관리자에 의해 차단된 템플릿입니다. 자세한 내용은 문의 해주세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2010', '', '템플릿에 사용하는 샘플 이미지가 등록되지 않았습니다. 샘플 이미지를 등록 해주세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2011', '', '이미지 해시아이디에 해당하는 파트너키나 템플릿그룹키를 사용해야합니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2101', '', '템플릿에 저장된 템플릿그룹 아이디와 일치하지 않는 템플릿 요청입니다. 템플릿 설정을 확인해주세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2102', '', '유효하지 않은 템플릿그룹키 입니다. 그룹키를 확인해주세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2103', '', '템플릿그룹의 파트너 목록에 존재하지 않는 요청입니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '2104', '', '이미지 해시 아이디에 해당하는 템플릿그룹키를 확인해주세요.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '3001', '', '에이전트 키에 해당하는 파트너가 매핑되어 있지 않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '3002', '', '전화번호에 해당하는 유저가 존재하지않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '3003', '', '매핑된 파트너가 존재하지 않습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '3004', '', '이미 존재하는 메세지키 입니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '3005', '', '전화번호에 해당하는 서로 다른 유저가 존재합니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '4001', '', '유저가 정보성 알림을 받을 수 있는 상태가 아닙니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '4002', '', '유저가 스마트알림 수신을 차단하였습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '4003', '', '유저가 파트너계정을 차단하였습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '9051', '', '메세지 시스템의 오류로 정보성 알림 송신이 불가합니다. 주로 톡톡메세지를 보내다가 발생하는 오류이며, 자세한 오류코드는 점차 업데이트 하겠습니다.');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NAVER', '9999', '', '알 수 없는 이유로 메세지가 전송되지 않았습니다.');

-- 가온(내부) 에러코드
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G100', '', 'APP_GUBUN에KAKAO, NAVER 이외의값이입력됨(대문자만입력가능)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G101', '', '전화번호에러');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G200', '', 'TEMPLATE_CODE 테이블에템플릿이존재하지않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G201', '', '버튼의JSON형식이맞지않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G202', '', '버튼이존재하나url이http:// 혹은https://로시작하지않음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G300', '', '메시지내용이빈값');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G301', '', 'GAON_MSG_TYPE이S인경우내용이90Byte 초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G400', '', '각번호별일일발송량초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G777', '', 'TEST BED');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G900', '', '서버연결실패');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G901', '', '인증실패');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G902', '', '타임아웃');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('GAON', 'G903', '', '메시지내용이제한길이를초과하였으나euc-kr기준으로2000byte 이하로문자발송');

-- 누리 에러코드
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', '0', '', '성공');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'f', '', 'MMS G/W 자체 형식 오류');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', '1', '', 'TIMEOUT');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'g', '', 'SMS/LMS/MMS 서비스 불가 단말기');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'A', '', '핸드폰 호 처리 중');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'h', '', '핸드폰 호 불가 상태');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'B', '', '음영지역');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'i', '', 'SMC 운영자가 메시지 삭제');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'C', '', 'power off');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'j', '', '이통사 내부 메시지 Que Full');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'D', '', '메시지 저장개수 초과');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'k', '', '이통사에서 spam 처리');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', '2', '', '잘못된 전화번호');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'l', '', 'www.nospam.go.kr 에 등록된 번호에 대해  G/W에서 spam 처리한 건');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'a', '', '일시 서비스 정지');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'm', '', 'MMS G/W에서 Spam 처리한 건(1.2.x: 90초과시)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'b', '', '기타 단말기 문제');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'n', '', '건수제안에 걸린 경우 (건수제안 계약이 되어 있는 경우)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'c', '', '착신 거절');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'o', '', '메시지의 길이가 제안된 길이를 벗어난 경우');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'd', '', '기타, 발신도용 차단, 용량초과 등 운영에 문의');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'p', '', '폰 번호가 형식에 어긋난 경우');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'e', '', '이통사 SMC 형식 오류, 무선망 전송실패(추, 미납, SMS 미납, 선불)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'Q', '', '필드 형식이 잘못된 경우 (예:데이터 내용이 없는 경우)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 's', '', '메시지 스팸차단(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'x', '', 'MMS 콘텐트의 정보를 참조할 수 없음');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'u', '', 'BARCODE 생성 실패');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'r', '', '회신번호 스팸차단(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'q', '', '메시지 중복키 체크(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'y', '', '하루에 한 수신번호에 보낼수 있는 메시지 수량초과(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'w', '', 'SMS 전송문자에 특정키워드가 없으면 SPAM 처리하여 메시지 전송제한(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 't', '', '스팸차단 중 2개 이상 중복 차단(Nuri 내부)');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'z', '', '처리 되지 않은 기타오류');
INSERT INTO app_error_code (APP_GUBUN, APP_CODE, MESSAGE, DESCRIPTION) VALUES('NURI', 'Z', '', '메시지 접수시 기타 실패');
